pub enum NecFrameDecodeError {
AddressMismatch,
DataMismatch,
AddressAndDataMismatch,
}Expand description
NEC frames send the address and data as normal and inverted bits. These are the errors you can get when trying to decode a raw Frame
Variants
AddressMismatch
Address and inverted address did not match
DataMismatch
Data and inverted data did not match
AddressAndDataMismatch
Both address and data do not match the inverted value